@@ -1,10 +1,8 @@
-# -*- coding: utf-8 -*-
 """Gaussian formchk plugin."""
-from __future__ import absolute_import
 
-from aiida.orm import List, RemoteData, SinglefileData, Str, Bool
 from aiida.common import CalcInfo, CodeInfo
 from aiida.engine import CalcJob
+from aiida.orm import Bool, RemoteData, Str
 
 
 class FormchkCalculation(CalcJob):
@@ -18,31 +16,31 @@ class FormchkCalculation(CalcJob):
 
     @classmethod
     def define(cls, spec):
-        super(FormchkCalculation, cls).define(spec)
+        super().define(spec)
 
         spec.input(
-            'parent_calc_folder',
+            "parent_calc_folder",
             valid_type=RemoteData,
             required=True,
-            help='the folder of a containing the .chk'
+            help="the folder of a containing the .chk",
         )
         spec.input(
-            'chk_name',
+            "chk_name",
             valid_type=Str,
             required=False,
             default=lambda: Str(cls.DEFAULT_INPUT_FILE),
-            help="name of the checkpoint file"
+            help="name of the checkpoint file",
         )
         spec.input(
-            'retrieve_fchk',
+            "retrieve_fchk",
             valid_type=Bool,
             required=False,
             default=lambda: Bool(False),
-            help="retrieve the fchk file"
+            help="retrieve the fchk file",
         )
 
         # Turn mpi off by default
-        spec.input('metadata.options.withmpi', valid_type=bool, default=False)
+        spec.input("metadata.options.withmpi", valid_type=bool, default=False)
 
     # --------------------------------------------------------------------------
     def prepare_for_submission(self, folder):
@@ -51,7 +49,8 @@ class FormchkCalculation(CalcJob):
         codeinfo = CodeInfo()
         codeinfo.code_uuid = self.inputs.code.uuid
         codeinfo.cmdline_params = [
-            self.PARENT_FOLDER_NAME + "/" + self.inputs.chk_name.value, self.DEFAULT_OUTPUT_FILE
+            self.PARENT_FOLDER_NAME + "/" + self.inputs.chk_name.value,
+            self.DEFAULT_OUTPUT_FILE,
         ]
         codeinfo.withmpi = self.inputs.metadata.options.withmpi
 
@@ -70,7 +69,9 @@ class FormchkCalculation(CalcJob):
         comp_uuid = self.inputs.parent_calc_folder.computer.uuid
         remote_path = self.inputs.parent_calc_folder.get_remote_path()
         copy_info = (comp_uuid, remote_path, self.PARENT_FOLDER_NAME)
-        if self.inputs.code.computer.uuid == comp_uuid:  # if running on the same computer - make a symlink
+        if (
+            self.inputs.code.computer.uuid == comp_uuid
+        ):  # if running on the same computer - make a symlink
             # if not - copy the folder
             calcinfo.remote_symlink_list.append(copy_info)
         else:
