@@ -1,16 +1,17 @@
-# -*- coding: utf-8 -*-
 """Base work chain to run a Gaussian calculation."""
 
 from aiida.common import AttributeDict
-
-from aiida.engine import process_handler, ProcessHandlerReport
-from aiida.engine import BaseRestartWorkChain, while_
+from aiida.engine import (
+    BaseRestartWorkChain,
+    ProcessHandlerReport,
+    process_handler,
+    while_,
+)
 from aiida.orm import Dict
-
 from aiida.plugins import CalculationFactory, DataFactory
 
-GaussianCalculation = CalculationFactory('gaussian')
-StructureData = DataFactory('structure')
+GaussianCalculation = CalculationFactory("gaussian")
+StructureData = DataFactory("core.structure")
 
 
 class GaussianBaseWorkChain(BaseRestartWorkChain):
@@ -21,8 +22,8 @@ class GaussianBaseWorkChain(BaseRestartWorkChain):
     @classmethod
     def define(cls, spec):
 
-        super(GaussianBaseWorkChain, cls).define(spec)
-        spec.expose_inputs(GaussianCalculation, namespace='gaussian')
+        super().define(spec)
+        spec.expose_inputs(GaussianCalculation, namespace="gaussian")
 
         spec.outline(
             cls.setup,
@@ -37,31 +38,33 @@ class GaussianBaseWorkChain(BaseRestartWorkChain):
 
         spec.exit_code(
             350,
-            'ERROR_UNRECOVERABLE_SCF_FAILURE',
-            message='The calculation failed with an unrecoverable SCF convergence error.'
+            "ERROR_UNRECOVERABLE_SCF_FAILURE",
+            message="The calculation failed with an unrecoverable SCF convergence error.",
         )
 
         spec.exit_code(
             399,
-            'ERROR_UNRECOVERABLE_TERMINATION',
-            message='The calculation failed with an unrecoverable error.'
+            "ERROR_UNRECOVERABLE_TERMINATION",
+            message="The calculation failed with an unrecoverable error.",
         )
 
     def setup(self):
         """Call the `setup` and create the inputs dictionary in `self.ctx.inputs`.
-        
+
         This `self.ctx.inputs` dictionary will be used by the `BaseRestartWorkChain` to
         submit the calculations in the internal loop.
         """
-        super(GaussianBaseWorkChain, self).setup()
-        self.ctx.inputs = AttributeDict(self.exposed_inputs(GaussianCalculation, 'gaussian'))
+        super().setup()
+        self.ctx.inputs = AttributeDict(
+            self.exposed_inputs(GaussianCalculation, "gaussian")
+        )
 
     @process_handler(
         priority=400,
         exit_codes=[
             GaussianCalculation.exit_codes.ERROR_SCF_FAILURE,
-            GaussianCalculation.exit_codes.ERROR_INACCURATE_QUADRATURE_CALDSU
-        ]
+            GaussianCalculation.exit_codes.ERROR_INACCURATE_QUADRATURE_CALDSU,
+        ],
     )
     def handle_scf_failure(self, node):
         """
@@ -72,36 +75,40 @@ class GaussianBaseWorkChain(BaseRestartWorkChain):
         """
 
         params = dict(self.ctx.inputs.parameters)
-        route_params = params['route_parameters']
+        route_params = params["route_parameters"]
 
-        if 'scf' not in route_params:
-            route_params['scf'] = {}
+        if "scf" not in route_params:
+            route_params["scf"] = {}
 
-        if 'xqc' in route_params['scf']:
+        if "xqc" in route_params["scf"]:
             # XQC and YQC failed:
             self.report("SCF failed with YQC and XQC, giving up...")
-            return ProcessHandlerReport(True, self.exit_codes.ERROR_UNRECOVERABLE_SCF_FAILURE)  # pylint: disable=no-member
+            return ProcessHandlerReport(
+                True, self.exit_codes.ERROR_UNRECOVERABLE_SCF_FAILURE
+            )  # pylint: disable=no-member
 
         new_scf = {}
         # keep the user-set convergence criterion; replace rest
-        if 'conver' in route_params['scf']:
-            new_scf['conver'] = route_params['scf']['conver']
+        if "conver" in route_params["scf"]:
+            new_scf["conver"] = route_params["scf"]["conver"]
 
-        if 'yqc' in route_params['scf']:
+        if "yqc" in route_params["scf"]:
             self.report("SCF=(YQC) failed, retrying with SCF=(XQC)")
-            new_scf['xqc'] = None
+            new_scf["xqc"] = None
         else:
             self.report("SCF failed, retrying with SCF=(YQC)")
-            new_scf['yqc'] = None
+            new_scf["yqc"] = None
 
         # Update the params Dict
-        route_params['scf'] = new_scf
-        self.ctx.inputs.parameters = Dict(dict=params)
+        route_params["scf"] = new_scf
+        self.ctx.inputs.parameters = Dict(params)
 
         return ProcessHandlerReport(True)
 
     @process_handler(
-        priority=500, exit_codes=[GaussianCalculation.exit_codes.ERROR_ASYTOP], enabled=False
+        priority=500,
+        exit_codes=[GaussianCalculation.exit_codes.ERROR_ASYTOP],
+        enabled=False,
     )
     def handle_asytop_error(self, node):
         """Handle the error code 302 (ASYTOP)."""
@@ -114,14 +121,17 @@ class GaussianBaseWorkChain(BaseRestartWorkChain):
         return ProcessHandlerReport(True)
 
     @process_handler(
-        priority=0, exit_codes=[GaussianCalculation.exit_codes.ERROR_NO_NORMAL_TERMINATION]
+        priority=0,
+        exit_codes=[GaussianCalculation.exit_codes.ERROR_NO_NORMAL_TERMINATION],
     )
     def handle_misc_failure(self, node):
         """
         By default, the BaseRestartWorkChain restarts any unhandled error once
         Disable this feature for the exit_code that corresponds to out-of-time
         """
-        return ProcessHandlerReport(False, self.exit_codes.ERROR_UNRECOVERABLE_TERMINATION)  # pylint: disable=no-member
+        return ProcessHandlerReport(
+            False, self.exit_codes.ERROR_UNRECOVERABLE_TERMINATION
+        )  # pylint: disable=no-member
 
     def results(self):
         """Overload the method such that each dynamic output of GaussianCalculation is set."""
@@ -133,12 +143,14 @@ class GaussianBaseWorkChain(BaseRestartWorkChain):
         max_iterations = self.inputs.max_iterations.value  # type: ignore[union-attr]
         if not self.ctx.is_finished and self.ctx.iteration >= max_iterations:
             self.report(
-                f'reached the maximum number of iterations {max_iterations}: '
-                f'last ran {self.ctx.process_name}<{node.pk}>'
+                f"reached the maximum number of iterations {max_iterations}: "
+                f"last ran {self.ctx.process_name}<{node.pk}>"
             )
-            return self.exit_codes.ERROR_MAXIMUM_ITERATIONS_EXCEEDED  # pylint: disable=no-member
+            return (
+                self.exit_codes.ERROR_MAXIMUM_ITERATIONS_EXCEEDED
+            )  # pylint: disable=no-member
 
-        self.report(f'The work chain completed after {self.ctx.iteration} iterations')
+        self.report(f"The work chain completed after {self.ctx.iteration} iterations")
 
         self.out_many({key: node.outputs[key] for key in node.outputs})
 
